@@ -145,7 +145,14 @@ class ModuleScope(Scope):
 # Globally defined names which are not attributes of the __builtin__ module.
 _MAGIC_GLOBALS = ['__file__', '__builtins__']
 
-
+def getNodeName(node):
+    # Returns node.id, or node.name, or None
+    if hasattr(node, 'id'): # One of the many nodes with an id
+        return node.id
+    elif hasattr(node, 'name'): # a ExceptHandler node
+        return node.name
+    else:
+        return None
 
 class Checker:
     """
@@ -172,17 +179,17 @@ class Checker:
         self.scopeStack = [ModuleScope()]
         self.futuresAllowed = True
         self.handleChildren(tree)
-        self._runDeferred(self._deferredFunctions)
+        self.runDeferred(self._deferredFunctions)
         # Set _deferredFunctions to None so that deferFunction will fail
         # noisily if called after we've run through the deferred functions.
         self._deferredFunctions = None
-        self._runDeferred(self._deferredAssignments)
+        self.runDeferred(self._deferredAssignments)
         # Set _deferredAssignments to None so that deferAssignment will fail
         # noisly if called after we've run through the deferred assignments.
         self._deferredAssignments = None
         del self.scopeStack[1:]
         self.popScope()
-        self.check_dead_scopes()
+        self.checkDeadScopes()
 
 
     def deferFunction(self, callable):
@@ -205,7 +212,7 @@ class Checker:
         self._deferredAssignments.append((callable, self.scopeStack[:]))
 
 
-    def _runDeferred(self, deferred):
+    def runDeferred(self, deferred):
         """
         Run the callables in C{deferred} using their associated scope stack.
         """
@@ -213,16 +220,14 @@ class Checker:
             self.scopeStack = scope
             handler()
 
-
+    @property
     def scope(self):
         return self.scopeStack[-1]
-    scope = property(scope)
 
     def popScope(self):
         self.dead_scopes.append(self.scopeStack.pop())
 
-
-    def check_dead_scopes(self):
+    def checkDeadScopes(self):
         """
         Look at scopes which have been fully examined and report names in them
         which were imported but unused.
@@ -261,7 +266,43 @@ class Checker:
     def report(self, messageClass, *args, **kwargs):
         self.messages.append(messageClass(self.filename, *args, **kwargs))
     
-    def handleNameLoad(self, name, node):
+    def addBinding(self, lineno, value, reportRedef=True):
+        '''Called when a binding is altered.
+
+        - `lineno` is the line of the statement responsible for the change
+        - `value` is the optional new value, a Binding instance, associated
+          with the binding; if None, the binding is deleted if it exists.
+        - if `reportRedef` is True (default), rebinding while unused will be
+          reported.
+        '''
+        if (isinstance(self.scope.get(value.name), FunctionDefinition)
+                    and isinstance(value, FunctionDefinition)):
+            self.report(messages.RedefinedFunction,
+                        lineno, value.name, self.scope[value.name].source.lineno)
+
+        if not isinstance(self.scope, ClassScope):
+            for scope in self.scopeStack[::-1]:
+                existing = scope.get(value.name)
+                if (isinstance(existing, Importation)
+                        and not existing.used
+                        and (not isinstance(value, Importation) or value.fullName == existing.fullName)
+                        and reportRedef):
+
+                    self.report(messages.RedefinedWhileUnused,
+                                lineno, value.name, scope[value.name].source.lineno)
+
+        if isinstance(value, UnBinding):
+            try:
+                del self.scope[value.name]
+            except KeyError:
+                self.report(messages.UndefinedName, lineno, value.name)
+        else:
+            self.scope[value.name] = value
+    
+    def handleNodeLoad(self, node):
+        name = getNodeName(node)
+        if not name:
+            return
         # try local scope
         importStarred = self.scope.importStarred
         try:
@@ -295,7 +336,10 @@ class Checker:
                 else:
                     self.report(messages.UndefinedName, node.lineno, name)
     
-    def handleNameStore(self, name, node):
+    def handleNodeStore(self, node):
+        name = getNodeName(node)
+        if not name:
+            return
         # if the name hasn't already been defined in the current scope
         if isinstance(self.scope, FunctionScope) and name not in self.scope:
             # for each function or module scope above us
@@ -312,17 +356,21 @@ class Checker:
                         scope[name].source.lineno)
                     break
 
-        if isinstance(node.parent, (ast.For, ast.comprehension, ast.Tuple, ast.List)):
+        parent = getattr(node, 'parent', None)
+        if isinstance(parent, (ast.For, ast.comprehension, ast.Tuple, ast.List)):
             binding = Binding(name, node)
-        elif (name == '__all__' and isinstance(self.scope, ModuleScope)):
-            binding = ExportBinding(name, node.parent.value)
+        elif parent is not None and name == '__all__' and isinstance(self.scope, ModuleScope):
+            binding = ExportBinding(name, parent.value)
         else:
             binding = Assignment(name, node)
         if name in self.scope:
             binding.used = self.scope[name].used
         self.addBinding(node.lineno, binding)
     
-    def handleNameDelete(self, name, node):
+    def handleNodeDelete(self, node):
+        name = getNodeName(node)
+        if not name:
+            return
         if isinstance(self.scope, FunctionScope) and name in self.scope.globals:
             del self.scope.globals[name]
         else:
@@ -387,45 +435,13 @@ class Checker:
     # additional node types
     COMPREHENSION = KEYWORD = handleChildren
 
-    def addBinding(self, lineno, value, reportRedef=True):
-        '''Called when a binding is altered.
-
-        - `lineno` is the line of the statement responsible for the change
-        - `value` is the optional new value, a Binding instance, associated
-          with the binding; if None, the binding is deleted if it exists.
-        - if `reportRedef` is True (default), rebinding while unused will be
-          reported.
-        '''
-        if (isinstance(self.scope.get(value.name), FunctionDefinition)
-                    and isinstance(value, FunctionDefinition)):
-            self.report(messages.RedefinedFunction,
-                        lineno, value.name, self.scope[value.name].source.lineno)
-
-        if not isinstance(self.scope, ClassScope):
-            for scope in self.scopeStack[::-1]:
-                existing = scope.get(value.name)
-                if (isinstance(existing, Importation)
-                        and not existing.used
-                        and (not isinstance(value, Importation) or value.fullName == existing.fullName)
-                        and reportRedef):
-
-                    self.report(messages.RedefinedWhileUnused,
-                                lineno, value.name, scope[value.name].source.lineno)
-
-        if isinstance(value, UnBinding):
-            try:
-                del self.scope[value.name]
-            except KeyError:
-                self.report(messages.UndefinedName, lineno, value.name)
-        else:
-            self.scope[value.name] = value
-
     def GLOBAL(self, node):
         """
         Keep track of globals declarations.
         """
         if isinstance(self.scope, FunctionScope):
             self.scope.globals.update(dict.fromkeys(node.names))
+    NONLOCAL = GLOBAL
 
     def LISTCOMP(self, node):
         # handle generators before element
@@ -435,7 +451,6 @@ class Checker:
 
     GENERATOREXP = SETCOMP = LISTCOMP
 
-    # dictionary comprehensions; introduced in Python 2.7
     def DICTCOMP(self, node):
         for gen in node.generators:
             self.handleNode(gen, node)
@@ -472,24 +487,19 @@ class Checker:
         """
         # Locate the name in locals / function / globals scopes.
         if isinstance(node.ctx, (ast.Load, ast.AugLoad)):
-            self.handleNameLoad(node.id, node)
+            self.handleNodeLoad(node)
         elif isinstance(node.ctx, (ast.Store, ast.AugStore)):
-            self.handleNameStore(node.id, node)
+            self.handleNodeStore(node)
         elif isinstance(node.ctx, ast.Del):
-            self.handleNameDelete(node.id, node)
+            self.handleNodeDelete(node)
         else:
             # must be a Param context -- this only happens for names in function
             # arguments, but these aren't dispatched through here
             raise RuntimeError("Got impossible expression context: %r" % (node.ctx,))
 
     def FUNCTIONDEF(self, node):
-        # the decorators attribute is called decorator_list as of Python 2.6
-        if hasattr(node, 'decorators'):
-            for deco in node.decorators:
-                self.handleNode(deco, node)
-        else:
-            for deco in node.decorator_list:
-                self.handleNode(deco, node)
+        for deco in node.decorator_list:
+            self.handleNode(deco, node)
         self.addBinding(node.lineno, FunctionDefinition(node.name, node))
         self.LAMBDA(node)
 
@@ -547,8 +557,7 @@ class Checker:
         classes, and the body of its definition.  Additionally, add its name to
         the current scope.
         """
-        # decorator_list is present as of Python 2.6
-        for deco in getattr(node, 'decorator_list', []):
+        for deco in node.decorator_list:
             self.handleNode(deco, node)
         for baseNode in node.bases:
             self.handleNode(baseNode, node)
@@ -564,13 +573,9 @@ class Checker:
             self.handleNode(target, node)
 
     def AUGASSIGN(self, node):
-        # AugAssign is awkward: must set the context explicitly and visit twice,
-        # once with AugLoad context, once with AugStore context
-        node.target.ctx = ast.AugLoad()
-        self.handleNode(node.target, node)
-        self.handleNode(node.value, node)
-        node.target.ctx = ast.AugStore()
-        self.handleNode(node.target, node)
+        self.handleNodeLoad(node.target)
+        self.handleNodeLoad(node.value)
+        self.handleNodeStore(node.target)
 
     def IMPORT(self, node):
         for alias in node.names:
@@ -601,6 +606,6 @@ class Checker:
         # in addition to handling children, we must handle the name of the exception, which is not
         # a Name node, but a simple string.
         if node.name:
-            self.handleNameStore(node.name, node)
+            self.handleNodeStore(node)
         self.handleChildren(node)
         
\ No newline at end of file
