@@ -1,6 +1,6 @@
 
 import textwrap
-import _ast
+import ast
 
 import unittest
 
@@ -10,9 +10,8 @@ from pyflakes import checker
 class Test(unittest.TestCase):
 
     def flakes(self, input, *expectedOutputs, **kw):
-        ast = compile(textwrap.dedent(input), "<test>", "exec",
-                      _ast.PyCF_ONLY_AST)
-        w = checker.Checker(ast, **kw)
+        compiled_ast = compile(textwrap.dedent(input), "<test>", "exec", ast.PyCF_ONLY_AST)
+        w = checker.Checker(compiled_ast, **kw)
         outputs = [type(o) for o in w.messages]
         expectedOutputs = list(expectedOutputs)
         outputs.sort(key=lambda t: t.__name__)
