@@ -183,6 +183,19 @@ class Test(harness.Test):
         [1, 2][x,:]
         ''')
 
+    def test_const_augassign(self):
+        """Augmented assignment of a constant is supported. We don't care about const refs"""
+        self.flakes('''
+        foo = 0
+        foo += 1
+        ''')
+    
+    def test_attr_augassign(self):
+        """Augmented assignment of attributes is supported. We don't care about attr refs"""
+        self.flakes('''
+        foo = None
+        foo.bar += foo.baz
+        ''')
 
 
 class TestUnusedAssignment(harness.Test):
@@ -213,7 +226,18 @@ class TestUnusedAssignment(harness.Test):
             b = 1
         ''')
 
-
+    def test_assignToNonlocal(self):
+        """
+        Assigning to a nonlocal and then not using that binding is perfectly
+        acceptable. Do not mistake it for an unused local variable.
+        """
+        self.flakes('''
+        b = 0
+        def a():
+            nonlocal b
+            b = 1
+        ''')
+    
     def test_assignToMember(self):
         """
         Assigning to a member of another object and then not using that member
